#!/usr/bin/env python3
# -*- coding: utf-8 -*-

""" Field IDs. """

__version__ = '2.2.0.22'

from pr22.types import PrEnum, chk_ver
chk_ver(__version__)


class FieldId(PrEnum):
    """ Field IDs. Use it as processing.FieldId. """
    All                    = 0,         "All fields."
    Composite1             = 1,         "Not specified / composite data #1."
    Composite2             = 2,         "Not specified / composite data #2."
    Composite3             = 3,         "Not specified / composite data #3."
    Composite4             = 4,         "Not specified / composite data #4."
    Composite5             = 5,         "Not specified / composite data #5."
    Name                   = 101,       "Full name."
    Givenname              = 102,       "Given name."
    Surname                = 103,       "Family name."
    Surname2               = 104,       "Family name 2nd."
    MiddleName             = 105,       "Middle name."
    MaidenName             = 107,       "Full name at the time of birth."
    MaidenGivenname        = 108,       "Given name at the time of birth."
    MaidenSurname          = 109,       "Family name at the time of birth."
    NameTitle              = 110,       "Name title."
    BirthDate              = 113,       "Date of birth."
    BirthPlace             = 114,       "Place of birth."
    BirthCountry           = 115,       "Country of birth."
    MotherName             = 116,       "Mother's full name."
    MotherGivenname        = 117,       "Mother's given name."
    MotherSurname          = 118,       "Mother's family name."
    Nationality            = 119,       "Nationality."
    Sex                    = 120,       "Gender."
    BirthProvince          = 121,       "Province of birth."
    ParentsName            = 122,       "Given name of the parents."
    FatherName             = 123,       "Father's full name."
    MaritalStatus          = 124,       "Marital status."
    FatherGivenname        = 125,       "Father's given name."
    FatherSurname          = 126,       "Father's family name."
    DocumentNumber         = 130,       "Document number."
    Type                   = 131,       "Type of document as stated by the document."
    IssueCountry           = 132,       "Issuing country."
    IssuePlace             = 133,       "Place of issue."
    IssueState             = 134,       "State of issue."
    IssueDate              = 135,       "Date of issue."
    ExpiryDate             = 136,       "Date of expiry."
    IssueOrg               = 137,       "Issuing organization."
    ProvisionalEndDate     = 138,       "End of provisional period."
    PersonalNumber         = 140,       "Personal identification number."
    HealthInsNumber        = 141,       "Health insurance identification number."
    RegistrationNumber     = 142,       "Registration number."
    DUFNumber              = 143,       "DUF number."
    CAN                    = 144,       "Card access number."
    DocType                = 149,       "Type of document as recognized by the engine."
    DocPage                = 150,       "Page of the document as recognized by the engine."
    DocTypeDisc            = 151,       "Document type discriminator."
    PersonalData1          = 160,       "Additional personal data #1."
    PersonalData2          = 161,       "Additional personal data #2."
    Address                = 200,       "Full address."
    AddressZip             = 201,       "Address zip code."
    AddressCity            = 202,       "Address city."
    AddressStreet          = 203,       "Address street."
    AddressHouse           = 204,       "Address building number."
    AddressFlat            = 205,       "Address flat number."
    AddressDate            = 206,       "Registration date of the address."
    AddressState           = 209,       "Address state."
    AddressProvince        = 210,       "Address province."
    AddressMunicipality    = 212,       "Address municipality."
    AddressCountry         = 213,       "Address country."
    TempAddress            = 220,       "Full temporary address."
    TempAddressZip         = 221,       "Temporary address zip code."
    TempAddressCity        = 222,       "Temporary address city."
    TempAddressStreet      = 223,       "Temporary address street."
    TempAddressHouse       = 224,       "Temporary address building number."
    TempAddressFlat        = 225,       "Temporary address flat number."
    TempAddressDate        = 226,       "Registration date of temporary address."
    TempAddressDateEnd     = 227,       "Expiry date of temporary address."
    TempAddressState       = 229,       "Temporary address State."
    TempAddressProvince    = 230,       "Temporary address province."
    TempAddressMunicipality = 232,      "Temporary address municipality."
    ValidArea              = 240,       "Validity area."
    StartOfValidity        = 241,       "Start of validity."
    NumberOfEntries        = 242,       "Number of entries."
    DurationOfStay         = 243,       "Duration of stay."
    BankAccount            = 302,       "Bank account number."
    FromAddress            = 320,       "Source address."
    DestAddress            = 321,       "Destination address."
    FlightNo               = 322,       "Flight number."
    Compartment            = 323,       "Compartment."
    SeatNo                 = 324,       "Seat number."
    CheckInSequenceNo      = 325,       "Check in sequence number."
    Face                   = 400,       "Face."
    SecondaryFace          = 409,       "Secondary, low quality face photo."
    CompositeMrz           = 410,       "Composite Mrz data stored in other sources."
    Signature              = 420,       "Signature."
    Fingerprint            = 430,       "Fingerprint."
    Iris                   = 440,       "Iris."
    BiometricData          = 450,       "Biometric data block."
    Height                 = 490,       "Height."
    Weight                 = 491,       "Weight."
    EyeColor               = 492,       "Eye color."
    HairColor              = 493,       "Hair color."
    Authenticity           = 500,       "General authenticity."
    Authenticity1          = 501,       "Authenticity #1."
    Authenticity2          = 502,       "Authenticity #2."
    Authenticity3          = 503,       "Authenticity #3."
    Authenticity4          = 504,       "Authenticity #4."
    Authenticity5          = 505,       "Authenticity #5."
    Telephone              = 600,       "Telephone number."
    Profession             = 601,       "Profession."
    Title                  = 602,       "Title."
    PersonalSummary        = 603,       "Personal summary."
    ProofOfCitizenship     = 604,       "Proof of citizenship."
    OtherTdNumbers         = 605,       "Other travel document numbers."
    CustodyInformation     = 606,       "Custody information."
    OtherName              = 607,       "Other name."
    OtherPeople            = 608,       "Other people."
    Observations           = 609,       "Observations."
    Tax                    = 610,       "Tax/exit requirements."
    FrontImage             = 611,       "Image of front page of the document."
    RearImage              = 612,       "Image of back page of the document."
    PersonalizationDate    = 613,       "Date of personalization."
    PersonalizationSystem  = 614,       "Serial number of personalization device."
    OrganDonor             = 615,       "Organ donor."
    Remarks                = 616,       "Remarks."
    BloodType              = 617,       "Blood type."
    Rank                   = 618,       "Rank."
    ServiceBranch          = 619,       "Service branch."
    CAR                    = 620,       "Certification Authority Reference."
    CHR                    = 621,       "Certificate Holder Reference."
    Email                  = 622,       "e-mail address."
    Age                    = 623,       "Current age."
    Signer                 = 624,       "Signer identifier."
    LowLevel               = 997, "Signals that optical recognition level information are needed."
    FormatCheck            = 998,       "Signals that quality assurance information are needed."
    DocumentDescriptor     = 999,       "ECard table of contents data."
    B900                   = 1551,      "B900 ink check."
    CompositeVizAuth       = 2500,      "Composite VIZ authentication."
    UVDullCheck            = 2551,      "UV-dull paper check."
    SecurityFibres         = 2553,      "Security fibres."
    UVDullPhotoCheck       = 2560,      "UV-dull photo check."
    COM                    = 0x4001f4,  "ECard COM file."
    _Rf                    = 0x4001f4
    DG1                    = _Rf +  1,  "ECard DataGroup 1."
    DG2                    = _Rf +  2,  "ECard DataGroup 2."
    DG3                    = _Rf +  3,  "ECard DataGroup 3."
    DG4                    = _Rf +  4,  "ECard DataGroup 4."
    DG5                    = _Rf +  5,  "ECard DataGroup 5."
    DG6                    = _Rf +  6,  "ECard DataGroup 6."
    DG7                    = _Rf +  7,  "ECard DataGroup 7."
    DG8                    = _Rf +  8,  "ECard DataGroup 8."
    DG9                    = _Rf +  9,  "ECard DataGroup 9."
    DG10                   = _Rf + 10,  "ECard DataGroup 10."
    DG11                   = _Rf + 11,  "ECard DataGroup 11."
    DG12                   = _Rf + 12,  "ECard DataGroup 12."
    DG13                   = _Rf + 13,  "ECard DataGroup 13."
    DG14                   = _Rf + 14,  "ECard DataGroup 14."
    DG15                   = _Rf + 15,  "ECard DataGroup 15."
    DG16                   = _Rf + 16,  "ECard DataGroup 16."
    CardAccess             = _Rf + 28,  "ECard Card Access file."
    CardSecurity           = _Rf + 29,  "ECard Card Security file."
    CVCA                   = _Rf + 30,  "ECard CVCA file."
    SOD                    = _Rf + 31,  "ECard SOD file."
    CertDS                 = _Rf + 32,  "Document Signer certificate file."
    CertCSCA               = _Rf + 33,  "Country Signing CA certificate file."
    AuthPassive            = _Rf + 51,  "ECard passive authentication."
    AuthTerminal           = _Rf + 52,  "ECard terminal authentication."
    AuthPACE               = _Rf + 53,  "ECard password authenticated connection establishment."
    AuthBAC                = _Rf + 54,  "ECard basic access control authentication."
    AuthChip               = _Rf + 55,  "ECard chip authentication."
    AuthActive             = _Rf + 56,  "ECard active authentication."
    AuthSelectApp          = _Rf + 57,  "ECard select application."
    AuthBAP                = _Rf + 58,  "ECard basic access protection."
    AuthBlock              = _Rf + 59,  "ECard block authentication."
    AuthInitTerminal       = _Rf + 60,  "ECard initialize terminal authentication."
    AuthCompleteTerminal   = _Rf + 61,  "ECard complete terminal authentication."
    AuthStorageCard        = _Rf + 62,  "ECard storage card authentication."
